@@ -12,7 +12,7 @@ test_that("test matrix restore with soft-svd", {
   m_restored_svd = svd_ground_true$u[, seq_k] %*% diag(x = svd_ground_true$d[seq_k]) %*% t(svd_ground_true$v[, seq_k])
   m_restored_soft_svd = svd_soft_svd$u %*% diag(x = svd_soft_svd$d) %*% t(svd_soft_svd$v)
 
-  expect_equal(m_restored_svd, m_restored_soft_svd, tolerance = 1e-1)
+  expect_equivalent(m_restored_svd, m_restored_soft_svd, tolerance = 1e-1)
 })
 
 test_that("test soft-impute", {
